@@ -4,18 +4,25 @@ import pathlib
 import yaml
 import onnx
 import urllib.request
+from urllib.parse import urlparse
+
+from PyQt5.QtCore import QCoreApplication
 
-# Temporarily disable SSL verification
 import ssl
 
-ssl._create_default_https_context = ssl._create_unverified_context
+ssl._create_default_https_context = (
+    ssl._create_unverified_context
+)  # Prevent issue when downloading models behind a proxy
+
+import socket
+
+socket.setdefaulttimeout(240)  # Prevent timeout when downloading models
 
 from abc import abstractmethod
 
 
 from PyQt5.QtCore import QFile, QObject
 from PyQt5.QtGui import QImage
-from PyQt5.QtCore import QCoreApplication
 
 from .types import AutoLabelingResult
 from anylabeling.views.labeling.label_file import LabelFile, LabelFileError
@@ -40,13 +47,21 @@ class Model(QObject):
         # Load and check config
         if isinstance(model_config, str):
             if not os.path.isfile(model_config):
-                raise Exception(f"Config file not found: {model_config}")
+                raise FileNotFoundError(
+                    QCoreApplication.translate(
+                        "Model", "Config file not found: {model_config}"
+                    ).format(model_config=model_config)
+                )
             with open(model_config, "r") as f:
                 self.config = yaml.safe_load(f)
         elif isinstance(model_config, dict):
             self.config = model_config
         else:
-            raise Exception(f"Unknown config type: {type(model_config)}")
+            raise ValueError(
+                QCoreApplication.translate(
+                    "Model", "Unknown config type: {type}"
+                ).format(type=type(model_config))
+            )
         self.check_missing_config(
             config_names=self.Meta.required_config_names,
             config=self.config,
@@ -59,90 +74,30 @@ class Model(QObject):
         """
         return self.Meta.widgets
 
-    def get_model_abs_path(self, model_path, model_folder_name):
+    def get_model_abs_path(self, model_config, model_path_field_name):
         """
         Get model absolute path from config path or download from url
         """
         # Try getting model path from config folder
-        model_abs_path = os.path.abspath(model_path)
-        if os.path.exists(model_abs_path):
+        config_folder = os.path.dirname(model_config["config_file"])
+        model_path = model_config[model_path_field_name]
+        if os.path.isfile(os.path.join(config_folder, model_path)):
+            model_abs_path = os.path.abspath(
+                os.path.join(config_folder, model_path)
+            )
             return model_abs_path
 
-        self.on_message(
-            QCoreApplication.translate(
-                "Model", "Downloading model from registry..."
-            )
-        )
-
-        # Build download url
-        filename = os.path.basename(model_path)
-        if model_path.startswith("anylabeling_assets/"):
-            download_url = (
-                self.BASE_DOWNLOAD_URL
-                + model_path[len("anylabeling_assets/") :]
-            )
-        elif model_path.startswith(("http://", "https://")):
-            download_url = model_path
-        else:
-            raise Exception(
-                f"Unknown model path: {model_path}. "
-                "Model path must start with anylabeling_assets/ or "
-                "http:// or https://"
-            )
-
-        # Create model folder
+        # Try getting model from assets folder
         home_dir = os.path.expanduser("~")
         model_abs_path = os.path.abspath(
             os.path.join(
                 home_dir,
                 "anylabeling_data",
                 "models",
-                model_folder_name,
-                filename,
+                model_config["name"],
+                model_path,
             )
         )
-        if os.path.exists(model_abs_path):
-            if model_abs_path.lower().endswith(".onnx"):
-                try:
-                    onnx.checker.check_model(model_abs_path)
-                except onnx.checker.ValidationError as e:
-                    logging.warning("The model is invalid: %s", str(e))
-                    logging.warning("Action: Delete and redownload...")
-                    os.remove(model_abs_path)
-                else:
-                    return model_abs_path
-            else:
-                return model_abs_path
-        pathlib.Path(model_abs_path).parent.mkdir(parents=True, exist_ok=True)
-
-        # Download url
-        ellipsis_download_url = download_url
-        if len(download_url) > 40:
-            ellipsis_download_url = (
-                download_url[:20] + "..." + download_url[-20:]
-            )
-        logging.info(
-            "Downloading %s to %s", ellipsis_download_url, model_abs_path
-        )
-        try:
-            # Download and show progress
-            def _progress(count, block_size, total_size):
-                percent = int(count * block_size * 100 / total_size)
-                self.on_message(
-                    QCoreApplication.translate(
-                        "Model", "Downloading {download_url}: {percent}%"
-                    ).format(
-                        download_url=ellipsis_download_url, percent=percent
-                    )
-                )
-
-            urllib.request.urlretrieve(
-                download_url, model_abs_path, reporthook=_progress
-            )
-        except Exception as e:  # noqa
-            self.on_message(f"Could not download {download_url}")
-            raise Exception(f"Could not download {download_url}: {e}") from e
-
         return model_abs_path
 
     def check_missing_config(self, config_names, config):
