@@ -39,11 +39,13 @@ class YOLOv5(Model):
         # Run the parent class's init method
         super().__init__(model_config, on_message)
 
-        model_abs_path = self.get_model_abs_path(
-            self.config["model_path"], self.config["name"]
-        )
-        if not os.path.isfile(model_abs_path):
-            raise Exception(f"Model not found: {model_abs_path}")
+        model_abs_path = self.get_model_abs_path(self.config, "model_path")
+        if not model_abs_path or not os.path.isfile(model_abs_path):
+            raise FileNotFoundError(
+                QCoreApplication.translate(
+                    "Model", "Could not download or initialize YOLOv5 model."
+                )
+            )
 
         self.net = cv2.dnn.readNet(model_abs_path)
         if __preferred_device__ == "GPU":
