@@ -9,16 +9,32 @@ from .labeling.label_wrapper import LabelingWrapper
 class MainWindow(QMainWindow):
     """Main application window"""
 
-    def __init__(self, app):
+    def __init__(
+        self,
+        app,
+        config=None,
+        filename=None,
+        output=None,
+        output_file=None,
+        output_dir=None,
+    ):
         super().__init__()
         self.app = app
+        self.config = config
 
         self.setContentsMargins(0, 0, 0, 0)
         self.setWindowTitle(__appname__)
 
         main_layout = QVBoxLayout()
         main_layout.setContentsMargins(10, 10, 10, 10)
-        self.labeling_widget = LabelingWrapper(self)
+        self.labeling_widget = LabelingWrapper(
+            self,
+            config=config,
+            filename=filename,
+            output=output,
+            output_file=output_file,
+            output_dir=output_dir,
+        )
         main_layout.addWidget(self.labeling_widget)
         widget = QWidget()
         widget.setLayout(main_layout)
